import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal, 
  format
} from 'd3';

// legends and colors in Pie Chart
const sectionColors = [
  		'red', 'lightblue', 'yellow', 'lime', 'orange', 'skyblue', 'purple', 'wheat', 'turquoise', 'aqua'
		  ];

// URL dataset
const csvUrl = 'https://gist.githubusercontent.com/Amanullah007/7e9499bda32cbd841253171b80ba28d6/raw/7fee2f83326fec01730b683976911dc772525fc8/shop.csv';

// creating fucntion to fetch the url
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Text axex formatted
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Displaying pie chart on the window
const render = (data, total) => {
  const pieData = pie().value(d=>d.weeksales)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Arc creation 
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.weeksales));
  
  // text of each secyion renderred
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.weeksales)))
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Rendeering data legends for identifying
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.weeksales));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Product);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.weeksales)));
}

// Function main call
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.weeksales = +d.weeksales;
    total += d.weeksales
  });
	render(data,total);
};
run();